/*
Copyright (c) 1998-2009 VIA Technologies, Inc. All Rights Reserved.
 
This PROPRIETARY SOURCE CODE contains proprietary information of VIA 
Technologies, Inc. (VIA); Contents of this file shall not be disclosed to any 3rd party, 
copied or duplicated in any form, in whole or in part without prior written consent of 
VIA.  THIS SOURCE CODE & ANY RELATED DOCUMENTATION 
(COLLECTIVELY SOFTWARE) ARE PROVIDED AS IS, WITH ALL FAULTS, & 
WITHOUT WARRANTY OF ANY KIND.  VIA DISCLAIMS ALL EXPRESS OR 
IMPLIED WARRANTIES.  USER ACKNOWLEDGES THAT PARTIES FOR ANY 
DAMAGES ARISING FROM USE OF SOFTWARE OR ITS DERIVATIVE, 
INCLUDING, W/O LIMITATION, LOSS OF USE, DATA OR PROFITS. USER
WHOLLY ASSUMES ALL RISK ARISING FROM USE & PERFORMANCE OF 
SOFTWARE
*/ 
 
#ifndef FDAPI_DISK_SMART_H_
#define FDAPI_DISK_SMART_H_

#include "fdapi_base.h"

#ifdef __cplusplus
extern "C" {
#endif

#ifndef	_WIN32_WCE
/************************************************************************
		Disk Info and SMART
************************************************************************/
#pragma pack(1)
/**
 * The structure can be used to get the specified Hard Disk information.
 *
 */
typedef struct
{
	char	szModelNumber[64];      ///< model number
	char	szSerialNumber[64];     ///< serial number
	DWORD	dwDiskSize;             ///< unit:MB, 1 MB = 1024 x 1024 byte
} TFDDiskInfo, *PTFDDiskInfo;

/**
 * The structure can be used to get SMART information from the specified hard disk.
 *
 */
typedef struct
{
	BYTE byAttrID;          ///< attribute id
	BYTE byAttrValue;       ///< current value at the attribute.
	BYTE byWorstValue;      ///< worst value at the attribute.
	BYTE byThreshold;       ///< threshold at the attribute.
	__int64	nRawValue;      ///< raw value at the attribute.
} TFDSmartInfo, *PTFDSmartInfo;
#pragma pack()


/**
 * Get the number of disks on your system.
 * Note: This function is not supported on Windows CE
 * @param pdwNum: Returns the number of disks.
 * @return   : Returns FD_S_OK if successful or FD_E_INVALID_ARG if pdwNum is NULL.
 */
FLITEDECK_API DWORD FDHdd_GetDiskCount(DWORD * pdwNum);

/**
 * Initialize the HDD module.
 * Note: This function is not supported on Windows CE
 * @param dwDiskId: the physical drive number you want to open. Hard disk numbers start at zero.
 * @param phHdd: a pointer to a variable that receives the HDD handle.
 * @return   :
 * FD_S_OK: The function is success.
 * FD_E_INVALID_ARG: phHdd is NULL.
 * FD_E_OUT_OF_MEMORY: out of memory.
 * FD_E_FAIL: The function fails.
 */
FLITEDECK_API DWORD FDHdd_Initialize(DWORD dwDiskId, HANDLE * phHdd);

/**
 * Uninitialize the HDD module.
 * Note: This function is not supported on Windows CE
 * @param phHdd: the Hdd handle received from FDHdd_Initialize.
 * @return   : Returns FD_S_OK if successful or FD_E_INVALID_ARG if phHdd is NULL.
 */
FLITEDECK_API DWORD FDHdd_Uninitialize(HANDLE * phHdd);

/**
 * Get the disk information.
 * Note: This function is not supported on Windows CE
 * @param hHdd: the Hdd handle of the specified disk received from FDHdd_Initialize.
 * @param pstDiskInfo: a pointer to a TFDDiskInfo structure that receives the disk information.
 * @return   :
 * FD_S_OK: The function is success.
 * FD_E_INVALID_ARG: if hHdd or pstDiskInfo is NULL.
 * FD_E_FAIL: The function fails.
 */
FLITEDECK_API DWORD FDHdd_GetDiskInfo(HANDLE hHdd, PTFDDiskInfo pstDiskInfo);

/**
 * Get the number of the SMART attributes of the specified disk.
 * Note: This function is not supported on Windows CE
 * @param hHdd: the Hdd handle of the specified disk received from FDHdd_Initialize.
 * @param pdwCount: a pointer to a variable that receives the number of SMART attributes.
 * @return   :
 * FD_S_OK: The function is success.
 * FD_E_INVALID_ARG: hHdd or pdwCount is NULL.
 * FD_E_FAIL: The function fails.
 */
FLITEDECK_API DWORD FDHdd_GetSmartAttrCount(HANDLE hHdd, DWORD *pdwCount);

/**
 * Get all the SMART attributes of the specified disk.
 * Note: This function is not supported on Windows CE
 * @param hHdd: the Hdd handle of the specified disk received from FDHdd_Initialize.
 * @param pstSmartInfo: a pointer to a structure that receives the all the SMART attributes of the specified disk.
 * @param dwCount: the number of SMART attributes.
 * @return   :
 * FD_S_OK: The function is success.
 * FD_E_INVALID_ARG: hHdd or pstSmartInfo is NULL.
 * FD_E_FAIL: The function fails.
 */
FLITEDECK_API DWORD FDHdd_GetSmartInfo(HANDLE hHdd, PTFDSmartInfo pstSmartInfo, DWORD dwCount);
#endif // _WIN32_WCE


#ifdef __cplusplus
} // extern C
#endif

#endif
