/*
Copyright (c) 1998-2009 VIA Technologies, Inc. All Rights Reserved.
 
This PROPRIETARY SOURCE CODE contains proprietary information of VIA 
Technologies, Inc. (VIA); Contents of this file shall not be disclosed to any 3rd party, 
copied or duplicated in any form, in whole or in part without prior written consent of 
VIA.  THIS SOURCE CODE & ANY RELATED DOCUMENTATION 
(COLLECTIVELY SOFTWARE) ARE PROVIDED AS IS, WITH ALL FAULTS, & 
WITHOUT WARRANTY OF ANY KIND.  VIA DISCLAIMS ALL EXPRESS OR 
IMPLIED WARRANTIES.  USER ACKNOWLEDGES THAT PARTIES FOR ANY 
DAMAGES ARISING FROM USE OF SOFTWARE OR ITS DERIVATIVE, 
INCLUDING, W/O LIMITATION, LOSS OF USE, DATA OR PROFITS. USER
WHOLLY ASSUMES ALL RISK ARISING FROM USE & PERFORMANCE OF 
SOFTWARE
*/ 
 
#ifndef FDAPI_PARTITION_H_
#define FDAPI_PARTITION_H_

#include "fdapi_base.h"

#ifdef __cplusplus
extern "C" {
#endif

/************************************************************************
		Hard drive info
************************************************************************/
/// unknown file system
#define FD_FS_UNKNOWN                     0
/// FAT file system
#define FD_FS_FAT                         1
/// FAT32 file system
#define FD_FS_FAT32                       2
/// NTFS file system
#define FD_FS_NTFS                        3
/// Virtual FAT file system
#define FD_FS_VFAT                        4
/// extended file system
#define FD_FS_EXT                         5
/// second extended file system
#define FD_FS_EXT2                        6
/// third extended file system
#define FD_FS_EXT3                        7
//#define FD_FS_FAT         1
//#define FD_FS_FAT         1

#pragma pack(1)
/**
 * The structure defined below can be used to get the drive information from the specified hard disk.
 *
 */
typedef struct
{
	DWORD	dwTotalSpace;       ///< unit: MB, 1MB = 1024 x 1024 bytes
	DWORD	dwAvailableSpace;   ///< unit: MB, 1MB = 1024 x 1024 bytes
	/// 0: Unknown, 1:FAT, 2:FAT32, 3:NTFS,
	/// 4:VFAT, 5:EXT, 6:EXT2, 7:EXT3
	DWORD	dwFileSystem;
	/// drive name.
	/// TCHAR is the sam as char on Windows XP and linux.
	/// TCHAR is the sam as wchar_t on Windows CE.
	TCHAR	szName[128];
} TFDHddriveInfo, *PTFDHddriveInfo;
#pragma pack()

/**
 * Get the number of drive(Windows XP, CE) or partition(Ubuntu) on your system.
 * @param pdwCount: Returns the number of drive or partition.
 * @return   : Returns FD_S_OK if successful or FD_E_INVALID_ARG if pdwCount is NULL.
 */
FLITEDECK_API DWORD FDHddInfo_GetCount(DWORD * pdwCount);

/**
 * Get the number of the drive information of the specified disk.
 * @param pInfo: a pointer to a structure that receives all of drive information of the specified disk.
 * @param dwCount: the number of drive.
 * @return   :
 * FD_S_OK: The function is success.
 * FD_E_INVALID_ARG: if pInfo is NULL.
 * FD_E_FAIL: The function fails.
 */
FLITEDECK_API DWORD FDHddInfo_GetInfo(PTFDHddriveInfo pInfo, DWORD dwCount);


#ifdef __cplusplus
} // extern C
#endif

#endif
